Command

Struct Command 

pub struct Command<'a> {
    pub command_pattern: CommandPattern<'a>,
    pub arguments: Vec<String>,
    pub options: Options,
}
Command generated from an appropriate defined CommandPattern. It stores information of the result command based on Args, therefore Command is a result type, and not a container.

Fields

  • command_patterns: Original CommandPattern from which this Command was generated. It is stored in order to call its callback field and to determine which command was matched.
  • arguments: Arguments generated following CommandPattern’s args_count field.
  • options: Options generated following CommandPattern’s option_patterns field.

Example

Command::new(
    Args::CommandLineArgs,
    &[
        CommandPattern::new(
            "exit",
            &[], // No arguments are accepted.
            &[], // No options are accepted.
            &|_, _| std::process:exit(0),
        ),
    ],
)

Fields

command_pattern: CommandPattern<'a>arguments: Vec<String>options: Options

Implementations

Source

impl<'a> Command<'a>

pub fn from_args( args: Args, command_patterns: &[CommandPattern<'a>], ) -> Result<Self, String>

Creates a new Command from commandargs’s Args.

Fields
  • args: Source of arguments used, refer to Args to know the possible variants that can be passed here.
  • command_patterns: Accepted CommandPattern’s used to get a result Command.
Example
Command::from_args(
    Args::CommandLineArgs,
    &[
        CommandPattern::new(
            "exit",
            &[], // No arguments are accepted.
            &[], // No options are accepted.
            &|_, _| std::process:exit(0),
        ),
    ],
)
pub fn execute(&'a self)

Execute the result command, by calling the callback field of the matched CommandPattern.